Revert "Revert adoption of CUDA indexing in general - this can only work with later versions of the compiler, just like module based dispatch, and thus must be guarded against usage in earlier (e.g. 1.6) versions."

This reverts commit d2fd1f5


[ROCm/hip commit: fbaf729f88]
This commit is contained in:
Alex Voicu
2017-11-29 21:36:29 +00:00
parent c58a083e96
commit fcc42f035e
62 ha cambiato i file con 152 aggiunte e 152 eliminazioni
@@ -35,7 +35,7 @@ THE SOFTWARE.
template<typename T>
__global__ void Inc(hipLaunchParm lp, T *Array){
int tx = threadIdx.x + blockIdx.x * blockDim.x;
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
Array[tx] = Array[tx] + T(1);
}